/*
 *  Copyright (C) 1999 Peter Amstutz
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of *the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307 USA 
 */

#ifndef _SIMPLEGFX_H_
#define _SIMPLEGFX_H_

void wgxDrawSimpleShot(struct Projectilepos_bal *prjpos, void *info);
void wgxDrawSimpleRedExplosion(void *info);
void wgxDrawSimpleBlueExplosion(void *info);
void wgxDrawSimpleGreenExplosion(void *info);
void wgxDrawSimpleBlankExplosion(void *info);
void wgxDrawSimpleOrangeExplosion(void *info);
void wgxDrawSimpleCyanExplosion(void *info);
void wgxDrawSimplePurpleExplosion(void *info);
#endif
